# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FirewallRuleArgs', 'FirewallRule']

@pulumi.input_type
class FirewallRuleArgs:
    def __init__(__self__, *,
                 action: pulumi.Input[builtins.str],
                 ip: pulumi.Input[builtins.str],
                 ip_on_firewall: pulumi.Input[builtins.str],
                 protocol: pulumi.Input[builtins.str],
                 sequence: pulumi.Input[builtins.float],
                 destination_port: Optional[pulumi.Input[builtins.float]] = None,
                 fragments: Optional[pulumi.Input[builtins.bool]] = None,
                 source: Optional[pulumi.Input[builtins.str]] = None,
                 source_port: Optional[pulumi.Input[builtins.float]] = None,
                 tcp_option: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a FirewallRule resource.
        :param pulumi.Input[builtins.str] action: Possible values for action (deny|permit)
        :param pulumi.Input[builtins.str] ip: The IP or the CIDR
        :param pulumi.Input[builtins.str] ip_on_firewall: IPv4 address
        :param pulumi.Input[builtins.str] protocol: Possible values for protocol (ah|esp|gre|icmp|ipv4|tcp|udp)
        :param pulumi.Input[builtins.float] sequence: Rule position in the rules array
        :param pulumi.Input[builtins.float] destination_port: Destination port for your rule. Only with TCP/UDP protocol
        :param pulumi.Input[builtins.bool] fragments: Fragments option
        :param pulumi.Input[builtins.str] source: IPv4 CIDR notation (e.g., 192.0.2.0/24)
        :param pulumi.Input[builtins.float] source_port: Source port for your rule. Only with TCP/UDP protocol
        :param pulumi.Input[builtins.str] tcp_option: TCP option on your rule (syn|established)
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "ip", ip)
        pulumi.set(__self__, "ip_on_firewall", ip_on_firewall)
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "sequence", sequence)
        if destination_port is not None:
            pulumi.set(__self__, "destination_port", destination_port)
        if fragments is not None:
            pulumi.set(__self__, "fragments", fragments)
        if source is not None:
            pulumi.set(__self__, "source", source)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if tcp_option is not None:
            pulumi.set(__self__, "tcp_option", tcp_option)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Input[builtins.str]:
        """
        Possible values for action (deny|permit)
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Input[builtins.str]:
        """
        The IP or the CIDR
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="ipOnFirewall")
    def ip_on_firewall(self) -> pulumi.Input[builtins.str]:
        """
        IPv4 address
        """
        return pulumi.get(self, "ip_on_firewall")

    @ip_on_firewall.setter
    def ip_on_firewall(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ip_on_firewall", value)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[builtins.str]:
        """
        Possible values for protocol (ah|esp|gre|icmp|ipv4|tcp|udp)
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def sequence(self) -> pulumi.Input[builtins.float]:
        """
        Rule position in the rules array
        """
        return pulumi.get(self, "sequence")

    @sequence.setter
    def sequence(self, value: pulumi.Input[builtins.float]):
        pulumi.set(self, "sequence", value)

    @property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Destination port for your rule. Only with TCP/UDP protocol
        """
        return pulumi.get(self, "destination_port")

    @destination_port.setter
    def destination_port(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "destination_port", value)

    @property
    @pulumi.getter
    def fragments(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Fragments option
        """
        return pulumi.get(self, "fragments")

    @fragments.setter
    def fragments(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "fragments", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv4 CIDR notation (e.g., 192.0.2.0/24)
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Source port for your rule. Only with TCP/UDP protocol
        """
        return pulumi.get(self, "source_port")

    @source_port.setter
    def source_port(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "source_port", value)

    @property
    @pulumi.getter(name="tcpOption")
    def tcp_option(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TCP option on your rule (syn|established)
        """
        return pulumi.get(self, "tcp_option")

    @tcp_option.setter
    def tcp_option(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tcp_option", value)


@pulumi.input_type
class _FirewallRuleState:
    def __init__(__self__, *,
                 action: Optional[pulumi.Input[builtins.str]] = None,
                 creation_date: Optional[pulumi.Input[builtins.str]] = None,
                 destination: Optional[pulumi.Input[builtins.str]] = None,
                 destination_port: Optional[pulumi.Input[builtins.float]] = None,
                 destination_port_desc: Optional[pulumi.Input[builtins.str]] = None,
                 fragments: Optional[pulumi.Input[builtins.bool]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 ip_on_firewall: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 sequence: Optional[pulumi.Input[builtins.float]] = None,
                 source: Optional[pulumi.Input[builtins.str]] = None,
                 source_port: Optional[pulumi.Input[builtins.float]] = None,
                 source_port_desc: Optional[pulumi.Input[builtins.str]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None,
                 tcp_option: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering FirewallRule resources.
        :param pulumi.Input[builtins.str] action: Possible values for action (deny|permit)
        :param pulumi.Input[builtins.str] creation_date: Creation date of the rule
        :param pulumi.Input[builtins.str] destination: Destination IP for your rule
        :param pulumi.Input[builtins.float] destination_port: Destination port for your rule. Only with TCP/UDP protocol
        :param pulumi.Input[builtins.str] destination_port_desc: String description of field `destination_port`
        :param pulumi.Input[builtins.bool] fragments: Fragments option
        :param pulumi.Input[builtins.str] ip: The IP or the CIDR
        :param pulumi.Input[builtins.str] ip_on_firewall: IPv4 address
        :param pulumi.Input[builtins.str] protocol: Possible values for protocol (ah|esp|gre|icmp|ipv4|tcp|udp)
        :param pulumi.Input[builtins.str] rule: Description of the rule
        :param pulumi.Input[builtins.float] sequence: Rule position in the rules array
        :param pulumi.Input[builtins.str] source: IPv4 CIDR notation (e.g., 192.0.2.0/24)
        :param pulumi.Input[builtins.float] source_port: Source port for your rule. Only with TCP/UDP protocol
        :param pulumi.Input[builtins.str] source_port_desc: String description of field `source_port`
        :param pulumi.Input[builtins.str] state: Current state of your rule
        :param pulumi.Input[builtins.str] tcp_option: TCP option on your rule (syn|established)
        """
        if action is not None:
            pulumi.set(__self__, "action", action)
        if creation_date is not None:
            pulumi.set(__self__, "creation_date", creation_date)
        if destination is not None:
            pulumi.set(__self__, "destination", destination)
        if destination_port is not None:
            pulumi.set(__self__, "destination_port", destination_port)
        if destination_port_desc is not None:
            pulumi.set(__self__, "destination_port_desc", destination_port_desc)
        if fragments is not None:
            pulumi.set(__self__, "fragments", fragments)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if ip_on_firewall is not None:
            pulumi.set(__self__, "ip_on_firewall", ip_on_firewall)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if sequence is not None:
            pulumi.set(__self__, "sequence", sequence)
        if source is not None:
            pulumi.set(__self__, "source", source)
        if source_port is not None:
            pulumi.set(__self__, "source_port", source_port)
        if source_port_desc is not None:
            pulumi.set(__self__, "source_port_desc", source_port_desc)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if tcp_option is not None:
            pulumi.set(__self__, "tcp_option", tcp_option)

    @property
    @pulumi.getter
    def action(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Possible values for action (deny|permit)
        """
        return pulumi.get(self, "action")

    @action.setter
    def action(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "action", value)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation date of the rule
        """
        return pulumi.get(self, "creation_date")

    @creation_date.setter
    def creation_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation_date", value)

    @property
    @pulumi.getter
    def destination(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Destination IP for your rule
        """
        return pulumi.get(self, "destination")

    @destination.setter
    def destination(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination", value)

    @property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Destination port for your rule. Only with TCP/UDP protocol
        """
        return pulumi.get(self, "destination_port")

    @destination_port.setter
    def destination_port(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "destination_port", value)

    @property
    @pulumi.getter(name="destinationPortDesc")
    def destination_port_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        String description of field `destination_port`
        """
        return pulumi.get(self, "destination_port_desc")

    @destination_port_desc.setter
    def destination_port_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_port_desc", value)

    @property
    @pulumi.getter
    def fragments(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Fragments option
        """
        return pulumi.get(self, "fragments")

    @fragments.setter
    def fragments(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "fragments", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IP or the CIDR
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="ipOnFirewall")
    def ip_on_firewall(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv4 address
        """
        return pulumi.get(self, "ip_on_firewall")

    @ip_on_firewall.setter
    def ip_on_firewall(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_on_firewall", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Possible values for protocol (ah|esp|gre|icmp|ipv4|tcp|udp)
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description of the rule
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter
    def sequence(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Rule position in the rules array
        """
        return pulumi.get(self, "sequence")

    @sequence.setter
    def sequence(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "sequence", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPv4 CIDR notation (e.g., 192.0.2.0/24)
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Source port for your rule. Only with TCP/UDP protocol
        """
        return pulumi.get(self, "source_port")

    @source_port.setter
    def source_port(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "source_port", value)

    @property
    @pulumi.getter(name="sourcePortDesc")
    def source_port_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        String description of field `source_port`
        """
        return pulumi.get(self, "source_port_desc")

    @source_port_desc.setter
    def source_port_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_port_desc", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current state of your rule
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="tcpOption")
    def tcp_option(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        TCP option on your rule (syn|established)
        """
        return pulumi.get(self, "tcp_option")

    @tcp_option.setter
    def tcp_option(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tcp_option", value)


class FirewallRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[builtins.str]] = None,
                 destination_port: Optional[pulumi.Input[builtins.float]] = None,
                 fragments: Optional[pulumi.Input[builtins.bool]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 ip_on_firewall: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 sequence: Optional[pulumi.Input[builtins.float]] = None,
                 source: Optional[pulumi.Input[builtins.str]] = None,
                 source_port: Optional[pulumi.Input[builtins.float]] = None,
                 tcp_option: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to manage a rule on an IP firewall.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_firewall_rule = ovh.ip.FirewallRule("my_firewall_rule",
            ip="XXXXXX",
            ip_on_firewall="XXXXXX",
            sequence=0,
            action="deny",
            protocol="tcp")
        ```

        ## Import

        The resource can be imported using the properties `ip`, `ip_on_firewall` and `sequence`, separated by "|" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Ip/firewallRule:FirewallRule my_firewall_rule '127.0.0.1|127.0.0.2|0'
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] action: Possible values for action (deny|permit)
        :param pulumi.Input[builtins.float] destination_port: Destination port for your rule. Only with TCP/UDP protocol
        :param pulumi.Input[builtins.bool] fragments: Fragments option
        :param pulumi.Input[builtins.str] ip: The IP or the CIDR
        :param pulumi.Input[builtins.str] ip_on_firewall: IPv4 address
        :param pulumi.Input[builtins.str] protocol: Possible values for protocol (ah|esp|gre|icmp|ipv4|tcp|udp)
        :param pulumi.Input[builtins.float] sequence: Rule position in the rules array
        :param pulumi.Input[builtins.str] source: IPv4 CIDR notation (e.g., 192.0.2.0/24)
        :param pulumi.Input[builtins.float] source_port: Source port for your rule. Only with TCP/UDP protocol
        :param pulumi.Input[builtins.str] tcp_option: TCP option on your rule (syn|established)
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FirewallRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to manage a rule on an IP firewall.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_firewall_rule = ovh.ip.FirewallRule("my_firewall_rule",
            ip="XXXXXX",
            ip_on_firewall="XXXXXX",
            sequence=0,
            action="deny",
            protocol="tcp")
        ```

        ## Import

        The resource can be imported using the properties `ip`, `ip_on_firewall` and `sequence`, separated by "|" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Ip/firewallRule:FirewallRule my_firewall_rule '127.0.0.1|127.0.0.2|0'
        ```

        :param str resource_name: The name of the resource.
        :param FirewallRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FirewallRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 action: Optional[pulumi.Input[builtins.str]] = None,
                 destination_port: Optional[pulumi.Input[builtins.float]] = None,
                 fragments: Optional[pulumi.Input[builtins.bool]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 ip_on_firewall: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 sequence: Optional[pulumi.Input[builtins.float]] = None,
                 source: Optional[pulumi.Input[builtins.str]] = None,
                 source_port: Optional[pulumi.Input[builtins.float]] = None,
                 tcp_option: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FirewallRuleArgs.__new__(FirewallRuleArgs)

            if action is None and not opts.urn:
                raise TypeError("Missing required property 'action'")
            __props__.__dict__["action"] = action
            __props__.__dict__["destination_port"] = destination_port
            __props__.__dict__["fragments"] = fragments
            if ip is None and not opts.urn:
                raise TypeError("Missing required property 'ip'")
            __props__.__dict__["ip"] = ip
            if ip_on_firewall is None and not opts.urn:
                raise TypeError("Missing required property 'ip_on_firewall'")
            __props__.__dict__["ip_on_firewall"] = ip_on_firewall
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            if sequence is None and not opts.urn:
                raise TypeError("Missing required property 'sequence'")
            __props__.__dict__["sequence"] = sequence
            __props__.__dict__["source"] = source
            __props__.__dict__["source_port"] = source_port
            __props__.__dict__["tcp_option"] = tcp_option
            __props__.__dict__["creation_date"] = None
            __props__.__dict__["destination"] = None
            __props__.__dict__["destination_port_desc"] = None
            __props__.__dict__["rule"] = None
            __props__.__dict__["source_port_desc"] = None
            __props__.__dict__["state"] = None
        super(FirewallRule, __self__).__init__(
            'ovh:Ip/firewallRule:FirewallRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            action: Optional[pulumi.Input[builtins.str]] = None,
            creation_date: Optional[pulumi.Input[builtins.str]] = None,
            destination: Optional[pulumi.Input[builtins.str]] = None,
            destination_port: Optional[pulumi.Input[builtins.float]] = None,
            destination_port_desc: Optional[pulumi.Input[builtins.str]] = None,
            fragments: Optional[pulumi.Input[builtins.bool]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            ip_on_firewall: Optional[pulumi.Input[builtins.str]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            sequence: Optional[pulumi.Input[builtins.float]] = None,
            source: Optional[pulumi.Input[builtins.str]] = None,
            source_port: Optional[pulumi.Input[builtins.float]] = None,
            source_port_desc: Optional[pulumi.Input[builtins.str]] = None,
            state: Optional[pulumi.Input[builtins.str]] = None,
            tcp_option: Optional[pulumi.Input[builtins.str]] = None) -> 'FirewallRule':
        """
        Get an existing FirewallRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] action: Possible values for action (deny|permit)
        :param pulumi.Input[builtins.str] creation_date: Creation date of the rule
        :param pulumi.Input[builtins.str] destination: Destination IP for your rule
        :param pulumi.Input[builtins.float] destination_port: Destination port for your rule. Only with TCP/UDP protocol
        :param pulumi.Input[builtins.str] destination_port_desc: String description of field `destination_port`
        :param pulumi.Input[builtins.bool] fragments: Fragments option
        :param pulumi.Input[builtins.str] ip: The IP or the CIDR
        :param pulumi.Input[builtins.str] ip_on_firewall: IPv4 address
        :param pulumi.Input[builtins.str] protocol: Possible values for protocol (ah|esp|gre|icmp|ipv4|tcp|udp)
        :param pulumi.Input[builtins.str] rule: Description of the rule
        :param pulumi.Input[builtins.float] sequence: Rule position in the rules array
        :param pulumi.Input[builtins.str] source: IPv4 CIDR notation (e.g., 192.0.2.0/24)
        :param pulumi.Input[builtins.float] source_port: Source port for your rule. Only with TCP/UDP protocol
        :param pulumi.Input[builtins.str] source_port_desc: String description of field `source_port`
        :param pulumi.Input[builtins.str] state: Current state of your rule
        :param pulumi.Input[builtins.str] tcp_option: TCP option on your rule (syn|established)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FirewallRuleState.__new__(_FirewallRuleState)

        __props__.__dict__["action"] = action
        __props__.__dict__["creation_date"] = creation_date
        __props__.__dict__["destination"] = destination
        __props__.__dict__["destination_port"] = destination_port
        __props__.__dict__["destination_port_desc"] = destination_port_desc
        __props__.__dict__["fragments"] = fragments
        __props__.__dict__["ip"] = ip
        __props__.__dict__["ip_on_firewall"] = ip_on_firewall
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["rule"] = rule
        __props__.__dict__["sequence"] = sequence
        __props__.__dict__["source"] = source
        __props__.__dict__["source_port"] = source_port
        __props__.__dict__["source_port_desc"] = source_port_desc
        __props__.__dict__["state"] = state
        __props__.__dict__["tcp_option"] = tcp_option
        return FirewallRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def action(self) -> pulumi.Output[builtins.str]:
        """
        Possible values for action (deny|permit)
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> pulumi.Output[builtins.str]:
        """
        Creation date of the rule
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter
    def destination(self) -> pulumi.Output[builtins.str]:
        """
        Destination IP for your rule
        """
        return pulumi.get(self, "destination")

    @property
    @pulumi.getter(name="destinationPort")
    def destination_port(self) -> pulumi.Output[builtins.float]:
        """
        Destination port for your rule. Only with TCP/UDP protocol
        """
        return pulumi.get(self, "destination_port")

    @property
    @pulumi.getter(name="destinationPortDesc")
    def destination_port_desc(self) -> pulumi.Output[builtins.str]:
        """
        String description of field `destination_port`
        """
        return pulumi.get(self, "destination_port_desc")

    @property
    @pulumi.getter
    def fragments(self) -> pulumi.Output[builtins.bool]:
        """
        Fragments option
        """
        return pulumi.get(self, "fragments")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        The IP or the CIDR
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="ipOnFirewall")
    def ip_on_firewall(self) -> pulumi.Output[builtins.str]:
        """
        IPv4 address
        """
        return pulumi.get(self, "ip_on_firewall")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        Possible values for protocol (ah|esp|gre|icmp|ipv4|tcp|udp)
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[builtins.str]:
        """
        Description of the rule
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter
    def sequence(self) -> pulumi.Output[builtins.float]:
        """
        Rule position in the rules array
        """
        return pulumi.get(self, "sequence")

    @property
    @pulumi.getter
    def source(self) -> pulumi.Output[builtins.str]:
        """
        IPv4 CIDR notation (e.g., 192.0.2.0/24)
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="sourcePort")
    def source_port(self) -> pulumi.Output[builtins.float]:
        """
        Source port for your rule. Only with TCP/UDP protocol
        """
        return pulumi.get(self, "source_port")

    @property
    @pulumi.getter(name="sourcePortDesc")
    def source_port_desc(self) -> pulumi.Output[builtins.str]:
        """
        String description of field `source_port`
        """
        return pulumi.get(self, "source_port_desc")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[builtins.str]:
        """
        Current state of your rule
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="tcpOption")
    def tcp_option(self) -> pulumi.Output[builtins.str]:
        """
        TCP option on your rule (syn|established)
        """
        return pulumi.get(self, "tcp_option")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetVrackNetworksResult',
    'AwaitableGetVrackNetworksResult',
    'get_vrack_networks',
    'get_vrack_networks_output',
]

@pulumi.output_type
class GetVrackNetworksResult:
    """
    A collection of values returned by getVrackNetworks.
    """
    def __init__(__self__, id=None, results=None, service_name=None, subnet=None, vlan_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if results and not isinstance(results, list):
            raise TypeError("Expected argument 'results' to be a list")
        pulumi.set(__self__, "results", results)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if subnet and not isinstance(subnet, str):
            raise TypeError("Expected argument 'subnet' to be a str")
        pulumi.set(__self__, "subnet", subnet)
        if vlan_id and not isinstance(vlan_id, int):
            raise TypeError("Expected argument 'vlan_id' to be a int")
        pulumi.set(__self__, "vlan_id", vlan_id)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def results(self) -> Sequence[builtins.int]:
        """
        The list of vrack network ids.
        """
        return pulumi.get(self, "results")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def subnet(self) -> Optional[builtins.str]:
        return pulumi.get(self, "subnet")

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> Optional[builtins.int]:
        return pulumi.get(self, "vlan_id")


class AwaitableGetVrackNetworksResult(GetVrackNetworksResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVrackNetworksResult(
            id=self.id,
            results=self.results,
            service_name=self.service_name,
            subnet=self.subnet,
            vlan_id=self.vlan_id)


def get_vrack_networks(service_name: Optional[builtins.str] = None,
                       subnet: Optional[builtins.str] = None,
                       vlan_id: Optional[builtins.int] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVrackNetworksResult:
    """
    Use this data source to get the list of Vrack network ids available for your IPLoadbalancer associated with your OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    lb_networks = ovh.get_vrack_networks(service_name="XXXXXX",
        subnet="10.0.0.0/24")
    ```


    :param builtins.str service_name: The internal name of your IP load balancing
    :param builtins.str subnet: Filters networks on the subnet.
    :param builtins.int vlan_id: Filters networks on the vlan id.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['subnet'] = subnet
    __args__['vlanId'] = vlan_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getVrackNetworks:getVrackNetworks', __args__, opts=opts, typ=GetVrackNetworksResult).value

    return AwaitableGetVrackNetworksResult(
        id=pulumi.get(__ret__, 'id'),
        results=pulumi.get(__ret__, 'results'),
        service_name=pulumi.get(__ret__, 'service_name'),
        subnet=pulumi.get(__ret__, 'subnet'),
        vlan_id=pulumi.get(__ret__, 'vlan_id'))
def get_vrack_networks_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                              subnet: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                              vlan_id: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVrackNetworksResult]:
    """
    Use this data source to get the list of Vrack network ids available for your IPLoadbalancer associated with your OVHcloud account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    lb_networks = ovh.get_vrack_networks(service_name="XXXXXX",
        subnet="10.0.0.0/24")
    ```


    :param builtins.str service_name: The internal name of your IP load balancing
    :param builtins.str subnet: Filters networks on the subnet.
    :param builtins.int vlan_id: Filters networks on the vlan id.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    __args__['subnet'] = subnet
    __args__['vlanId'] = vlan_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getVrackNetworks:getVrackNetworks', __args__, opts=opts, typ=GetVrackNetworksResult)
    return __ret__.apply(lambda __response__: GetVrackNetworksResult(
        id=pulumi.get(__response__, 'id'),
        results=pulumi.get(__response__, 'results'),
        service_name=pulumi.get(__response__, 'service_name'),
        subnet=pulumi.get(__response__, 'subnet'),
        vlan_id=pulumi.get(__response__, 'vlan_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .ds_records import *
from .get_zone import *
from .get_zone_dns_sec import *
from .name import *
from .name_servers import *
from .zone import *
from .zone_dns_sec import *
from .zone_import import *
from .zone_record import *
from .zone_redirection import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetLogsOutputOpenSearchIndexResult',
    'AwaitableGetLogsOutputOpenSearchIndexResult',
    'get_logs_output_open_search_index',
    'get_logs_output_open_search_index_output',
]

@pulumi.output_type
class GetLogsOutputOpenSearchIndexResult:
    """
    A collection of values returned by getLogsOutputOpenSearchIndex.
    """
    def __init__(__self__, alert_notify_enabled=None, created_at=None, current_size=None, description=None, id=None, index_id=None, is_editable=None, max_size=None, name=None, nb_shard=None, service_name=None, updated_at=None):
        if alert_notify_enabled and not isinstance(alert_notify_enabled, bool):
            raise TypeError("Expected argument 'alert_notify_enabled' to be a bool")
        pulumi.set(__self__, "alert_notify_enabled", alert_notify_enabled)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if current_size and not isinstance(current_size, int):
            raise TypeError("Expected argument 'current_size' to be a int")
        pulumi.set(__self__, "current_size", current_size)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if index_id and not isinstance(index_id, str):
            raise TypeError("Expected argument 'index_id' to be a str")
        pulumi.set(__self__, "index_id", index_id)
        if is_editable and not isinstance(is_editable, bool):
            raise TypeError("Expected argument 'is_editable' to be a bool")
        pulumi.set(__self__, "is_editable", is_editable)
        if max_size and not isinstance(max_size, int):
            raise TypeError("Expected argument 'max_size' to be a int")
        pulumi.set(__self__, "max_size", max_size)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if nb_shard and not isinstance(nb_shard, int):
            raise TypeError("Expected argument 'nb_shard' to be a int")
        pulumi.set(__self__, "nb_shard", nb_shard)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="alertNotifyEnabled")
    def alert_notify_enabled(self) -> builtins.bool:
        """
        If set, notify when size is near 80, 90 or 100 % of its maximum capacity
        """
        return pulumi.get(self, "alert_notify_enabled")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        Index creation
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="currentSize")
    def current_size(self) -> builtins.int:
        """
        Current index size (in bytes)
        """
        return pulumi.get(self, "current_size")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Index description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="indexId")
    def index_id(self) -> builtins.str:
        """
        Index ID
        """
        return pulumi.get(self, "index_id")

    @property
    @pulumi.getter(name="isEditable")
    def is_editable(self) -> builtins.bool:
        """
        Indicates if you are allowed to edit entry
        """
        return pulumi.get(self, "is_editable")

    @property
    @pulumi.getter(name="maxSize")
    def max_size(self) -> builtins.int:
        """
        Maximum index size (in bytes)
        """
        return pulumi.get(self, "max_size")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Index name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nbShard")
    def nb_shard(self) -> builtins.int:
        """
        Number of shard
        """
        return pulumi.get(self, "nb_shard")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        Index last update
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetLogsOutputOpenSearchIndexResult(GetLogsOutputOpenSearchIndexResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLogsOutputOpenSearchIndexResult(
            alert_notify_enabled=self.alert_notify_enabled,
            created_at=self.created_at,
            current_size=self.current_size,
            description=self.description,
            id=self.id,
            index_id=self.index_id,
            is_editable=self.is_editable,
            max_size=self.max_size,
            name=self.name,
            nb_shard=self.nb_shard,
            service_name=self.service_name,
            updated_at=self.updated_at)


def get_logs_output_open_search_index(name: Optional[builtins.str] = None,
                                      nb_shard: Optional[builtins.int] = None,
                                      service_name: Optional[builtins.str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLogsOutputOpenSearchIndexResult:
    """
    Use this data source to retrieve information about a DBaas logs output opensearch index.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    index = ovh.Dbaas.get_logs_output_open_search_index(service_name="ldp-xx-xxxxx",
        name="index-name")
    ```


    :param builtins.str name: Index name
    :param builtins.int nb_shard: Number of shard
    :param builtins.str service_name: The service name. It's the ID of your Logs Data Platform instance.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['nbShard'] = nb_shard
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Dbaas/getLogsOutputOpenSearchIndex:getLogsOutputOpenSearchIndex', __args__, opts=opts, typ=GetLogsOutputOpenSearchIndexResult).value

    return AwaitableGetLogsOutputOpenSearchIndexResult(
        alert_notify_enabled=pulumi.get(__ret__, 'alert_notify_enabled'),
        created_at=pulumi.get(__ret__, 'created_at'),
        current_size=pulumi.get(__ret__, 'current_size'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        index_id=pulumi.get(__ret__, 'index_id'),
        is_editable=pulumi.get(__ret__, 'is_editable'),
        max_size=pulumi.get(__ret__, 'max_size'),
        name=pulumi.get(__ret__, 'name'),
        nb_shard=pulumi.get(__ret__, 'nb_shard'),
        service_name=pulumi.get(__ret__, 'service_name'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_logs_output_open_search_index_output(name: Optional[pulumi.Input[builtins.str]] = None,
                                             nb_shard: Optional[pulumi.Input[Optional[builtins.int]]] = None,
                                             service_name: Optional[pulumi.Input[builtins.str]] = None,
                                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLogsOutputOpenSearchIndexResult]:
    """
    Use this data source to retrieve information about a DBaas logs output opensearch index.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    index = ovh.Dbaas.get_logs_output_open_search_index(service_name="ldp-xx-xxxxx",
        name="index-name")
    ```


    :param builtins.str name: Index name
    :param builtins.int nb_shard: Number of shard
    :param builtins.str service_name: The service name. It's the ID of your Logs Data Platform instance.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['nbShard'] = nb_shard
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Dbaas/getLogsOutputOpenSearchIndex:getLogsOutputOpenSearchIndex', __args__, opts=opts, typ=GetLogsOutputOpenSearchIndexResult)
    return __ret__.apply(lambda __response__: GetLogsOutputOpenSearchIndexResult(
        alert_notify_enabled=pulumi.get(__response__, 'alert_notify_enabled'),
        created_at=pulumi.get(__response__, 'created_at'),
        current_size=pulumi.get(__response__, 'current_size'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        index_id=pulumi.get(__response__, 'index_id'),
        is_editable=pulumi.get(__response__, 'is_editable'),
        max_size=pulumi.get(__response__, 'max_size'),
        name=pulumi.get(__response__, 'name'),
        nb_shard=pulumi.get(__response__, 'nb_shard'),
        service_name=pulumi.get(__response__, 'service_name'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ConnectResult',
    'AwaitableConnectResult',
    'connect',
    'connect_output',
]

@pulumi.output_type
class ConnectResult:
    """
    A collection of values returned by Connect.
    """
    def __init__(__self__, bandwidth=None, description=None, iam=None, id=None, interface_lists=None, pop=None, port_quantity=None, product=None, provider_name=None, service_name=None, status=None, uuid=None, vrack=None):
        if bandwidth and not isinstance(bandwidth, str):
            raise TypeError("Expected argument 'bandwidth' to be a str")
        pulumi.set(__self__, "bandwidth", bandwidth)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if iam and not isinstance(iam, dict):
            raise TypeError("Expected argument 'iam' to be a dict")
        pulumi.set(__self__, "iam", iam)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if interface_lists and not isinstance(interface_lists, list):
            raise TypeError("Expected argument 'interface_lists' to be a list")
        pulumi.set(__self__, "interface_lists", interface_lists)
        if pop and not isinstance(pop, str):
            raise TypeError("Expected argument 'pop' to be a str")
        pulumi.set(__self__, "pop", pop)
        if port_quantity and not isinstance(port_quantity, str):
            raise TypeError("Expected argument 'port_quantity' to be a str")
        pulumi.set(__self__, "port_quantity", port_quantity)
        if product and not isinstance(product, str):
            raise TypeError("Expected argument 'product' to be a str")
        pulumi.set(__self__, "product", product)
        if provider_name and not isinstance(provider_name, str):
            raise TypeError("Expected argument 'provider_name' to be a str")
        pulumi.set(__self__, "provider_name", provider_name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if uuid and not isinstance(uuid, str):
            raise TypeError("Expected argument 'uuid' to be a str")
        pulumi.set(__self__, "uuid", uuid)
        if vrack and not isinstance(vrack, str):
            raise TypeError("Expected argument 'vrack' to be a str")
        pulumi.set(__self__, "vrack", vrack)

    @property
    @pulumi.getter
    def bandwidth(self) -> builtins.str:
        """
        Service bandwidth
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Service description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def iam(self) -> 'outputs.ConnectIamResult':
        """
        IAM resource information
        """
        return pulumi.get(self, "iam")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="interfaceLists")
    def interface_lists(self) -> Sequence[builtins.float]:
        """
        List of interfaces linked to a service
        """
        return pulumi.get(self, "interface_lists")

    @property
    @pulumi.getter
    def pop(self) -> builtins.str:
        """
        Pop reference where the service is delivered
        """
        return pulumi.get(self, "pop")

    @property
    @pulumi.getter(name="portQuantity")
    def port_quantity(self) -> builtins.str:
        """
        Port quantity
        """
        return pulumi.get(self, "port_quantity")

    @property
    @pulumi.getter
    def product(self) -> builtins.str:
        """
        Product name of the service
        """
        return pulumi.get(self, "product")

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> builtins.str:
        """
        Service provider
        """
        return pulumi.get(self, "provider_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Service status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def uuid(self) -> builtins.str:
        """
        uuid of the Ovhcloud Connect service
        """
        return pulumi.get(self, "uuid")

    @property
    @pulumi.getter
    def vrack(self) -> builtins.str:
        """
        vrack linked to the service
        """
        return pulumi.get(self, "vrack")


class AwaitableConnectResult(ConnectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return ConnectResult(
            bandwidth=self.bandwidth,
            description=self.description,
            iam=self.iam,
            id=self.id,
            interface_lists=self.interface_lists,
            pop=self.pop,
            port_quantity=self.port_quantity,
            product=self.product,
            provider_name=self.provider_name,
            service_name=self.service_name,
            status=self.status,
            uuid=self.uuid,
            vrack=self.vrack)


def connect(service_name: Optional[builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableConnectResult:
    """
    Use this data source to retrieve information about an Ovhcloud Connect product

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    occ = ovh.OVHcloud.connect(service_name="XXX")
    ```


    :param builtins.str service_name: The uuid of the Ovhcloud connect.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:OVHcloud/connect:Connect', __args__, opts=opts, typ=ConnectResult).value

    return AwaitableConnectResult(
        bandwidth=pulumi.get(__ret__, 'bandwidth'),
        description=pulumi.get(__ret__, 'description'),
        iam=pulumi.get(__ret__, 'iam'),
        id=pulumi.get(__ret__, 'id'),
        interface_lists=pulumi.get(__ret__, 'interface_lists'),
        pop=pulumi.get(__ret__, 'pop'),
        port_quantity=pulumi.get(__ret__, 'port_quantity'),
        product=pulumi.get(__ret__, 'product'),
        provider_name=pulumi.get(__ret__, 'provider_name'),
        service_name=pulumi.get(__ret__, 'service_name'),
        status=pulumi.get(__ret__, 'status'),
        uuid=pulumi.get(__ret__, 'uuid'),
        vrack=pulumi.get(__ret__, 'vrack'))
def connect_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[ConnectResult]:
    """
    Use this data source to retrieve information about an Ovhcloud Connect product

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    occ = ovh.OVHcloud.connect(service_name="XXX")
    ```


    :param builtins.str service_name: The uuid of the Ovhcloud connect.
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:OVHcloud/connect:Connect', __args__, opts=opts, typ=ConnectResult)
    return __ret__.apply(lambda __response__: ConnectResult(
        bandwidth=pulumi.get(__response__, 'bandwidth'),
        description=pulumi.get(__response__, 'description'),
        iam=pulumi.get(__response__, 'iam'),
        id=pulumi.get(__response__, 'id'),
        interface_lists=pulumi.get(__response__, 'interface_lists'),
        pop=pulumi.get(__response__, 'pop'),
        port_quantity=pulumi.get(__response__, 'port_quantity'),
        product=pulumi.get(__response__, 'product'),
        provider_name=pulumi.get(__response__, 'provider_name'),
        service_name=pulumi.get(__response__, 'service_name'),
        status=pulumi.get(__response__, 'status'),
        uuid=pulumi.get(__response__, 'uuid'),
        vrack=pulumi.get(__response__, 'vrack')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetOkmsServiceKeyPemResult',
    'AwaitableGetOkmsServiceKeyPemResult',
    'get_okms_service_key_pem',
    'get_okms_service_key_pem_output',
]

@pulumi.output_type
class GetOkmsServiceKeyPemResult:
    """
    A collection of values returned by getOkmsServiceKeyPem.
    """
    def __init__(__self__, created_at=None, curve=None, iam=None, id=None, keys_pems=None, name=None, okms_id=None, operations=None, size=None, state=None, type=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if curve and not isinstance(curve, str):
            raise TypeError("Expected argument 'curve' to be a str")
        pulumi.set(__self__, "curve", curve)
        if iam and not isinstance(iam, dict):
            raise TypeError("Expected argument 'iam' to be a dict")
        pulumi.set(__self__, "iam", iam)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if keys_pems and not isinstance(keys_pems, list):
            raise TypeError("Expected argument 'keys_pems' to be a list")
        pulumi.set(__self__, "keys_pems", keys_pems)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if okms_id and not isinstance(okms_id, str):
            raise TypeError("Expected argument 'okms_id' to be a str")
        pulumi.set(__self__, "okms_id", okms_id)
        if operations and not isinstance(operations, list):
            raise TypeError("Expected argument 'operations' to be a list")
        pulumi.set(__self__, "operations", operations)
        if size and not isinstance(size, float):
            raise TypeError("Expected argument 'size' to be a float")
        pulumi.set(__self__, "size", size)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def curve(self) -> builtins.str:
        return pulumi.get(self, "curve")

    @property
    @pulumi.getter
    def iam(self) -> 'outputs.GetOkmsServiceKeyPemIamResult':
        return pulumi.get(self, "iam")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keysPems")
    def keys_pems(self) -> Sequence['outputs.GetOkmsServiceKeyPemKeysPemResult']:
        return pulumi.get(self, "keys_pems")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="okmsId")
    def okms_id(self) -> builtins.str:
        return pulumi.get(self, "okms_id")

    @property
    @pulumi.getter
    def operations(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "operations")

    @property
    @pulumi.getter
    def size(self) -> builtins.float:
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        return pulumi.get(self, "type")


class AwaitableGetOkmsServiceKeyPemResult(GetOkmsServiceKeyPemResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOkmsServiceKeyPemResult(
            created_at=self.created_at,
            curve=self.curve,
            iam=self.iam,
            id=self.id,
            keys_pems=self.keys_pems,
            name=self.name,
            okms_id=self.okms_id,
            operations=self.operations,
            size=self.size,
            state=self.state,
            type=self.type)


def get_okms_service_key_pem(id: Optional[builtins.str] = None,
                             okms_id: Optional[builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOkmsServiceKeyPemResult:
    """
    Use this data source to retrieve information about a KMS service key, in the PEM format.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['okmsId'] = okms_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Okms/getOkmsServiceKeyPem:getOkmsServiceKeyPem', __args__, opts=opts, typ=GetOkmsServiceKeyPemResult).value

    return AwaitableGetOkmsServiceKeyPemResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        curve=pulumi.get(__ret__, 'curve'),
        iam=pulumi.get(__ret__, 'iam'),
        id=pulumi.get(__ret__, 'id'),
        keys_pems=pulumi.get(__ret__, 'keys_pems'),
        name=pulumi.get(__ret__, 'name'),
        okms_id=pulumi.get(__ret__, 'okms_id'),
        operations=pulumi.get(__ret__, 'operations'),
        size=pulumi.get(__ret__, 'size'),
        state=pulumi.get(__ret__, 'state'),
        type=pulumi.get(__ret__, 'type'))
def get_okms_service_key_pem_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                    okms_id: Optional[pulumi.Input[builtins.str]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOkmsServiceKeyPemResult]:
    """
    Use this data source to retrieve information about a KMS service key, in the PEM format.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['okmsId'] = okms_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Okms/getOkmsServiceKeyPem:getOkmsServiceKeyPem', __args__, opts=opts, typ=GetOkmsServiceKeyPemResult)
    return __ret__.apply(lambda __response__: GetOkmsServiceKeyPemResult(
        created_at=pulumi.get(__response__, 'created_at'),
        curve=pulumi.get(__response__, 'curve'),
        iam=pulumi.get(__response__, 'iam'),
        id=pulumi.get(__response__, 'id'),
        keys_pems=pulumi.get(__response__, 'keys_pems'),
        name=pulumi.get(__response__, 'name'),
        okms_id=pulumi.get(__response__, 'okms_id'),
        operations=pulumi.get(__response__, 'operations'),
        size=pulumi.get(__response__, 'size'),
        state=pulumi.get(__response__, 'state'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCloudResult',
    'AwaitableGetCloudResult',
    'get_cloud',
    'get_cloud_output',
]

@pulumi.output_type
class GetCloudResult:
    """
    A collection of values returned by getCloud.
    """
    def __init__(__self__, advanced_security=None, bandwidth=None, billing_type=None, can_migrate_to_vcd=None, certified_interface_url=None, commercial_range=None, description=None, generation=None, iam=None, id=None, location=None, management_interface=None, product_reference=None, service_name=None, service_pack_name=None, spla=None, ssl_v3=None, state=None, user_access_policy=None, user_limit_concurrent_session=None, user_logout_policy=None, user_session_timeout=None, v_scope_url=None, version=None, web_interface_url=None):
        if advanced_security and not isinstance(advanced_security, bool):
            raise TypeError("Expected argument 'advanced_security' to be a bool")
        pulumi.set(__self__, "advanced_security", advanced_security)
        if bandwidth and not isinstance(bandwidth, str):
            raise TypeError("Expected argument 'bandwidth' to be a str")
        pulumi.set(__self__, "bandwidth", bandwidth)
        if billing_type and not isinstance(billing_type, str):
            raise TypeError("Expected argument 'billing_type' to be a str")
        pulumi.set(__self__, "billing_type", billing_type)
        if can_migrate_to_vcd and not isinstance(can_migrate_to_vcd, bool):
            raise TypeError("Expected argument 'can_migrate_to_vcd' to be a bool")
        pulumi.set(__self__, "can_migrate_to_vcd", can_migrate_to_vcd)
        if certified_interface_url and not isinstance(certified_interface_url, str):
            raise TypeError("Expected argument 'certified_interface_url' to be a str")
        pulumi.set(__self__, "certified_interface_url", certified_interface_url)
        if commercial_range and not isinstance(commercial_range, str):
            raise TypeError("Expected argument 'commercial_range' to be a str")
        pulumi.set(__self__, "commercial_range", commercial_range)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if generation and not isinstance(generation, str):
            raise TypeError("Expected argument 'generation' to be a str")
        pulumi.set(__self__, "generation", generation)
        if iam and not isinstance(iam, dict):
            raise TypeError("Expected argument 'iam' to be a dict")
        pulumi.set(__self__, "iam", iam)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if management_interface and not isinstance(management_interface, str):
            raise TypeError("Expected argument 'management_interface' to be a str")
        pulumi.set(__self__, "management_interface", management_interface)
        if product_reference and not isinstance(product_reference, str):
            raise TypeError("Expected argument 'product_reference' to be a str")
        pulumi.set(__self__, "product_reference", product_reference)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if service_pack_name and not isinstance(service_pack_name, str):
            raise TypeError("Expected argument 'service_pack_name' to be a str")
        pulumi.set(__self__, "service_pack_name", service_pack_name)
        if spla and not isinstance(spla, bool):
            raise TypeError("Expected argument 'spla' to be a bool")
        pulumi.set(__self__, "spla", spla)
        if ssl_v3 and not isinstance(ssl_v3, bool):
            raise TypeError("Expected argument 'ssl_v3' to be a bool")
        pulumi.set(__self__, "ssl_v3", ssl_v3)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if user_access_policy and not isinstance(user_access_policy, str):
            raise TypeError("Expected argument 'user_access_policy' to be a str")
        pulumi.set(__self__, "user_access_policy", user_access_policy)
        if user_limit_concurrent_session and not isinstance(user_limit_concurrent_session, float):
            raise TypeError("Expected argument 'user_limit_concurrent_session' to be a float")
        pulumi.set(__self__, "user_limit_concurrent_session", user_limit_concurrent_session)
        if user_logout_policy and not isinstance(user_logout_policy, str):
            raise TypeError("Expected argument 'user_logout_policy' to be a str")
        pulumi.set(__self__, "user_logout_policy", user_logout_policy)
        if user_session_timeout and not isinstance(user_session_timeout, float):
            raise TypeError("Expected argument 'user_session_timeout' to be a float")
        pulumi.set(__self__, "user_session_timeout", user_session_timeout)
        if v_scope_url and not isinstance(v_scope_url, str):
            raise TypeError("Expected argument 'v_scope_url' to be a str")
        pulumi.set(__self__, "v_scope_url", v_scope_url)
        if version and not isinstance(version, dict):
            raise TypeError("Expected argument 'version' to be a dict")
        pulumi.set(__self__, "version", version)
        if web_interface_url and not isinstance(web_interface_url, str):
            raise TypeError("Expected argument 'web_interface_url' to be a str")
        pulumi.set(__self__, "web_interface_url", web_interface_url)

    @property
    @pulumi.getter(name="advancedSecurity")
    def advanced_security(self) -> builtins.bool:
        """
        Advanced security state
        """
        return pulumi.get(self, "advanced_security")

    @property
    @pulumi.getter
    def bandwidth(self) -> builtins.str:
        """
        The current bandwidth of your VMware on OVHcloud
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> builtins.str:
        """
        Billing type of your VMware on OVHcloud
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="canMigrateToVcd")
    def can_migrate_to_vcd(self) -> builtins.bool:
        """
        Can the PCC be migrated to VCD
        """
        return pulumi.get(self, "can_migrate_to_vcd")

    @property
    @pulumi.getter(name="certifiedInterfaceUrl")
    def certified_interface_url(self) -> builtins.str:
        """
        Url to the VMware on OVHcloud certified interface
        """
        return pulumi.get(self, "certified_interface_url")

    @property
    @pulumi.getter(name="commercialRange")
    def commercial_range(self) -> builtins.str:
        """
        The current version of your VMware on OVHcloud
        """
        return pulumi.get(self, "commercial_range")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of your VMware on OVHcloud
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def generation(self) -> builtins.str:
        """
        Generation of your VMware on OVHcloud
        """
        return pulumi.get(self, "generation")

    @property
    @pulumi.getter
    def iam(self) -> 'outputs.GetCloudIamResult':
        """
        IAM resource metadata
        """
        return pulumi.get(self, "iam")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def location(self) -> builtins.str:
        """
        Datacenter where your VMware on OVHcloud is physically located
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="managementInterface")
    def management_interface(self) -> builtins.str:
        """
        The management interface name
        """
        return pulumi.get(self, "management_interface")

    @property
    @pulumi.getter(name="productReference")
    def product_reference(self) -> builtins.str:
        """
        The reference universe information for your VMware on OVHcloud
        """
        return pulumi.get(self, "product_reference")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Domain of the service
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="servicePackName")
    def service_pack_name(self) -> builtins.str:
        """
        Name of the current service pack
        """
        return pulumi.get(self, "service_pack_name")

    @property
    @pulumi.getter
    def spla(self) -> builtins.bool:
        """
        SPLA licensing state
        """
        return pulumi.get(self, "spla")

    @property
    @pulumi.getter(name="sslV3")
    def ssl_v3(self) -> builtins.bool:
        """
        Enable SSL v3 support. Warning : this option is not recommended as it was recognized as a security breach. If this is enabled, we advise you to enable the filtered User access policy
        """
        return pulumi.get(self, "ssl_v3")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        """
        Current state of your VMware on OVHcloud
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="userAccessPolicy")
    def user_access_policy(self) -> builtins.str:
        """
        Access policy of your VMware on OVHcloud : opened to every IPs or filtered
        """
        return pulumi.get(self, "user_access_policy")

    @property
    @pulumi.getter(name="userLimitConcurrentSession")
    def user_limit_concurrent_session(self) -> builtins.float:
        """
        The maximum amount of connected users allowed on the VMware on OVHcloud management interface
        """
        return pulumi.get(self, "user_limit_concurrent_session")

    @property
    @pulumi.getter(name="userLogoutPolicy")
    def user_logout_policy(self) -> builtins.str:
        """
        Which user will be disconnected first in case of quota of maximum connection is reached
        """
        return pulumi.get(self, "user_logout_policy")

    @property
    @pulumi.getter(name="userSessionTimeout")
    def user_session_timeout(self) -> builtins.float:
        """
        The timeout (in seconds) for the user sessions on the VMware on OVHcloud management interface. 0 value disable the timeout
        """
        return pulumi.get(self, "user_session_timeout")

    @property
    @pulumi.getter(name="vScopeUrl")
    def v_scope_url(self) -> builtins.str:
        """
        Url to the VMware on OVHcloud vScope interface
        """
        return pulumi.get(self, "v_scope_url")

    @property
    @pulumi.getter
    def version(self) -> 'outputs.GetCloudVersionResult':
        """
        Version of the management interface
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="webInterfaceUrl")
    def web_interface_url(self) -> builtins.str:
        """
        Url to the VMware on OVHcloud web interface
        """
        return pulumi.get(self, "web_interface_url")


class AwaitableGetCloudResult(GetCloudResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudResult(
            advanced_security=self.advanced_security,
            bandwidth=self.bandwidth,
            billing_type=self.billing_type,
            can_migrate_to_vcd=self.can_migrate_to_vcd,
            certified_interface_url=self.certified_interface_url,
            commercial_range=self.commercial_range,
            description=self.description,
            generation=self.generation,
            iam=self.iam,
            id=self.id,
            location=self.location,
            management_interface=self.management_interface,
            product_reference=self.product_reference,
            service_name=self.service_name,
            service_pack_name=self.service_pack_name,
            spla=self.spla,
            ssl_v3=self.ssl_v3,
            state=self.state,
            user_access_policy=self.user_access_policy,
            user_limit_concurrent_session=self.user_limit_concurrent_session,
            user_logout_policy=self.user_logout_policy,
            user_session_timeout=self.user_session_timeout,
            v_scope_url=self.v_scope_url,
            version=self.version,
            web_interface_url=self.web_interface_url)


def get_cloud(service_name: Optional[builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudResult:
    """
    Get information about a Managed VMware service.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    pcc = ovh.Dedicated.get_cloud(service_name="<Dedicated Cloud service name>")
    ```


    :param builtins.str service_name: Domain of the service
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Dedicated/getCloud:getCloud', __args__, opts=opts, typ=GetCloudResult).value

    return AwaitableGetCloudResult(
        advanced_security=pulumi.get(__ret__, 'advanced_security'),
        bandwidth=pulumi.get(__ret__, 'bandwidth'),
        billing_type=pulumi.get(__ret__, 'billing_type'),
        can_migrate_to_vcd=pulumi.get(__ret__, 'can_migrate_to_vcd'),
        certified_interface_url=pulumi.get(__ret__, 'certified_interface_url'),
        commercial_range=pulumi.get(__ret__, 'commercial_range'),
        description=pulumi.get(__ret__, 'description'),
        generation=pulumi.get(__ret__, 'generation'),
        iam=pulumi.get(__ret__, 'iam'),
        id=pulumi.get(__ret__, 'id'),
        location=pulumi.get(__ret__, 'location'),
        management_interface=pulumi.get(__ret__, 'management_interface'),
        product_reference=pulumi.get(__ret__, 'product_reference'),
        service_name=pulumi.get(__ret__, 'service_name'),
        service_pack_name=pulumi.get(__ret__, 'service_pack_name'),
        spla=pulumi.get(__ret__, 'spla'),
        ssl_v3=pulumi.get(__ret__, 'ssl_v3'),
        state=pulumi.get(__ret__, 'state'),
        user_access_policy=pulumi.get(__ret__, 'user_access_policy'),
        user_limit_concurrent_session=pulumi.get(__ret__, 'user_limit_concurrent_session'),
        user_logout_policy=pulumi.get(__ret__, 'user_logout_policy'),
        user_session_timeout=pulumi.get(__ret__, 'user_session_timeout'),
        v_scope_url=pulumi.get(__ret__, 'v_scope_url'),
        version=pulumi.get(__ret__, 'version'),
        web_interface_url=pulumi.get(__ret__, 'web_interface_url'))
def get_cloud_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudResult]:
    """
    Get information about a Managed VMware service.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    pcc = ovh.Dedicated.get_cloud(service_name="<Dedicated Cloud service name>")
    ```


    :param builtins.str service_name: Domain of the service
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Dedicated/getCloud:getCloud', __args__, opts=opts, typ=GetCloudResult)
    return __ret__.apply(lambda __response__: GetCloudResult(
        advanced_security=pulumi.get(__response__, 'advanced_security'),
        bandwidth=pulumi.get(__response__, 'bandwidth'),
        billing_type=pulumi.get(__response__, 'billing_type'),
        can_migrate_to_vcd=pulumi.get(__response__, 'can_migrate_to_vcd'),
        certified_interface_url=pulumi.get(__response__, 'certified_interface_url'),
        commercial_range=pulumi.get(__response__, 'commercial_range'),
        description=pulumi.get(__response__, 'description'),
        generation=pulumi.get(__response__, 'generation'),
        iam=pulumi.get(__response__, 'iam'),
        id=pulumi.get(__response__, 'id'),
        location=pulumi.get(__response__, 'location'),
        management_interface=pulumi.get(__response__, 'management_interface'),
        product_reference=pulumi.get(__response__, 'product_reference'),
        service_name=pulumi.get(__response__, 'service_name'),
        service_pack_name=pulumi.get(__response__, 'service_pack_name'),
        spla=pulumi.get(__response__, 'spla'),
        ssl_v3=pulumi.get(__response__, 'ssl_v3'),
        state=pulumi.get(__response__, 'state'),
        user_access_policy=pulumi.get(__response__, 'user_access_policy'),
        user_limit_concurrent_session=pulumi.get(__response__, 'user_limit_concurrent_session'),
        user_logout_policy=pulumi.get(__response__, 'user_logout_policy'),
        user_session_timeout=pulumi.get(__response__, 'user_session_timeout'),
        v_scope_url=pulumi.get(__response__, 'v_scope_url'),
        version=pulumi.get(__response__, 'version'),
        web_interface_url=pulumi.get(__response__, 'web_interface_url')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetMeCurrencyResult',
]

@pulumi.output_type
class GetMeCurrencyResult(dict):
    def __init__(__self__, *,
                 code: builtins.str,
                 symbol: builtins.str):
        """
        :param builtins.str code: Currency code used by this account (e.g EUR, USD, ...)
        :param builtins.str symbol: Currency symbol used by this account (e.g €, $, ...)
        """
        pulumi.set(__self__, "code", code)
        pulumi.set(__self__, "symbol", symbol)

    @property
    @pulumi.getter
    def code(self) -> builtins.str:
        """
        Currency code used by this account (e.g EUR, USD, ...)
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter
    def symbol(self) -> builtins.str:
        """
        Currency symbol used by this account (e.g €, $, ...)
        """
        return pulumi.get(self, "symbol")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPermissionsGroupsResult',
    'AwaitableGetPermissionsGroupsResult',
    'get_permissions_groups',
    'get_permissions_groups_output',
]

@pulumi.output_type
class GetPermissionsGroupsResult:
    """
    A collection of values returned by getPermissionsGroups.
    """
    def __init__(__self__, id=None, urns=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if urns and not isinstance(urns, list):
            raise TypeError("Expected argument 'urns' to be a list")
        pulumi.set(__self__, "urns", urns)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def urns(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "urns")


class AwaitableGetPermissionsGroupsResult(GetPermissionsGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPermissionsGroupsResult(
            id=self.id,
            urns=self.urns)


def get_permissions_groups(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPermissionsGroupsResult:
    """
    Use this data source to retrieve an IAM permissions group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    website = ovh.Iam.get_permissions_group(urn="urn:v1:eu:permissionsGroup:ovh:controlPanelAccess")
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Iam/getPermissionsGroups:getPermissionsGroups', __args__, opts=opts, typ=GetPermissionsGroupsResult).value

    return AwaitableGetPermissionsGroupsResult(
        id=pulumi.get(__ret__, 'id'),
        urns=pulumi.get(__ret__, 'urns'))
def get_permissions_groups_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPermissionsGroupsResult]:
    """
    Use this data source to retrieve an IAM permissions group.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    website = ovh.Iam.get_permissions_group(urn="urn:v1:eu:permissionsGroup:ovh:controlPanelAccess")
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Iam/getPermissionsGroups:getPermissionsGroups', __args__, opts=opts, typ=GetPermissionsGroupsResult)
    return __ret__.apply(lambda __response__: GetPermissionsGroupsResult(
        id=pulumi.get(__response__, 'id'),
        urns=pulumi.get(__response__, 'urns')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['IdentityGroupArgs', 'IdentityGroup']

@pulumi.input_type
class IdentityGroupArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 role: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a IdentityGroup resource.
        :param pulumi.Input[builtins.str] description: Group description.
        :param pulumi.Input[builtins.str] name: Group name.
        :param pulumi.Input[builtins.str] role: Role associated with the group. Valid roles are ADMIN, REGULAR, UNPRIVILEGED, and NONE.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if role is not None:
            pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Group description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Group name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Role associated with the group. Valid roles are ADMIN, REGULAR, UNPRIVILEGED, and NONE.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role", value)


@pulumi.input_type
class _IdentityGroupState:
    def __init__(__self__, *,
                 group_urn: Optional[pulumi.Input[builtins.str]] = None,
                 creation: Optional[pulumi.Input[builtins.str]] = None,
                 default_group: Optional[pulumi.Input[builtins.bool]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 last_update: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 role: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering IdentityGroup resources.
        :param pulumi.Input[builtins.str] group_urn: URN of the user group, used when writing IAM policies
        :param pulumi.Input[builtins.str] creation: Creation date of this group.
        :param pulumi.Input[builtins.bool] default_group: Is the group a default and immutable one.
        :param pulumi.Input[builtins.str] description: Group description.
        :param pulumi.Input[builtins.str] last_update: Date of the last update of this group.
        :param pulumi.Input[builtins.str] name: Group name.
        :param pulumi.Input[builtins.str] role: Role associated with the group. Valid roles are ADMIN, REGULAR, UNPRIVILEGED, and NONE.
        """
        if group_urn is not None:
            pulumi.set(__self__, "group_urn", group_urn)
        if creation is not None:
            pulumi.set(__self__, "creation", creation)
        if default_group is not None:
            pulumi.set(__self__, "default_group", default_group)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if last_update is not None:
            pulumi.set(__self__, "last_update", last_update)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if role is not None:
            pulumi.set(__self__, "role", role)

    @property
    @pulumi.getter(name="GroupURN")
    def group_urn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URN of the user group, used when writing IAM policies
        """
        return pulumi.get(self, "group_urn")

    @group_urn.setter
    def group_urn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_urn", value)

    @property
    @pulumi.getter
    def creation(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation date of this group.
        """
        return pulumi.get(self, "creation")

    @creation.setter
    def creation(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation", value)

    @property
    @pulumi.getter(name="defaultGroup")
    def default_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Is the group a default and immutable one.
        """
        return pulumi.get(self, "default_group")

    @default_group.setter
    def default_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "default_group", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Group description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the last update of this group.
        """
        return pulumi.get(self, "last_update")

    @last_update.setter
    def last_update(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "last_update", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Group name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Role associated with the group. Valid roles are ADMIN, REGULAR, UNPRIVILEGED, and NONE.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role", value)


class IdentityGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 role: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates an identity group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_group = ovh.me.IdentityGroup("my_group",
            description="Some custom description",
            name="my_group_name",
            role="NONE")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Group description.
        :param pulumi.Input[builtins.str] name: Group name.
        :param pulumi.Input[builtins.str] role: Role associated with the group. Valid roles are ADMIN, REGULAR, UNPRIVILEGED, and NONE.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[IdentityGroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an identity group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_group = ovh.me.IdentityGroup("my_group",
            description="Some custom description",
            name="my_group_name",
            role="NONE")
        ```

        :param str resource_name: The name of the resource.
        :param IdentityGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IdentityGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 role: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IdentityGroupArgs.__new__(IdentityGroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["role"] = role
            __props__.__dict__["group_urn"] = None
            __props__.__dict__["creation"] = None
            __props__.__dict__["default_group"] = None
            __props__.__dict__["last_update"] = None
        super(IdentityGroup, __self__).__init__(
            'ovh:Me/identityGroup:IdentityGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group_urn: Optional[pulumi.Input[builtins.str]] = None,
            creation: Optional[pulumi.Input[builtins.str]] = None,
            default_group: Optional[pulumi.Input[builtins.bool]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            last_update: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            role: Optional[pulumi.Input[builtins.str]] = None) -> 'IdentityGroup':
        """
        Get an existing IdentityGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] group_urn: URN of the user group, used when writing IAM policies
        :param pulumi.Input[builtins.str] creation: Creation date of this group.
        :param pulumi.Input[builtins.bool] default_group: Is the group a default and immutable one.
        :param pulumi.Input[builtins.str] description: Group description.
        :param pulumi.Input[builtins.str] last_update: Date of the last update of this group.
        :param pulumi.Input[builtins.str] name: Group name.
        :param pulumi.Input[builtins.str] role: Role associated with the group. Valid roles are ADMIN, REGULAR, UNPRIVILEGED, and NONE.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IdentityGroupState.__new__(_IdentityGroupState)

        __props__.__dict__["group_urn"] = group_urn
        __props__.__dict__["creation"] = creation
        __props__.__dict__["default_group"] = default_group
        __props__.__dict__["description"] = description
        __props__.__dict__["last_update"] = last_update
        __props__.__dict__["name"] = name
        __props__.__dict__["role"] = role
        return IdentityGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="GroupURN")
    def group_urn(self) -> pulumi.Output[builtins.str]:
        """
        URN of the user group, used when writing IAM policies
        """
        return pulumi.get(self, "group_urn")

    @property
    @pulumi.getter
    def creation(self) -> pulumi.Output[builtins.str]:
        """
        Creation date of this group.
        """
        return pulumi.get(self, "creation")

    @property
    @pulumi.getter(name="defaultGroup")
    def default_group(self) -> pulumi.Output[builtins.bool]:
        """
        Is the group a default and immutable one.
        """
        return pulumi.get(self, "default_group")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Group description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> pulumi.Output[builtins.str]:
        """
        Date of the last update of this group.
        """
        return pulumi.get(self, "last_update")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Group name.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Role associated with the group. Valid roles are ADMIN, REGULAR, UNPRIVILEGED, and NONE.
        """
        return pulumi.get(self, "role")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetNetworkPrivateSubnetsResult',
    'AwaitableGetNetworkPrivateSubnetsResult',
    'get_network_private_subnets',
    'get_network_private_subnets_output',
]

@pulumi.output_type
class GetNetworkPrivateSubnetsResult:
    """
    A collection of values returned by getNetworkPrivateSubnets.
    """
    def __init__(__self__, id=None, network_id=None, service_name=None, subnets=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if network_id and not isinstance(network_id, str):
            raise TypeError("Expected argument 'network_id' to be a str")
        pulumi.set(__self__, "network_id", network_id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if subnets and not isinstance(subnets, list):
            raise TypeError("Expected argument 'subnets' to be a list")
        pulumi.set(__self__, "subnets", subnets)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> builtins.str:
        """
        ID of the network
        """
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        ID of the public cloud project
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def subnets(self) -> Sequence['outputs.GetNetworkPrivateSubnetsSubnetResult']:
        """
        List of subnets
        """
        return pulumi.get(self, "subnets")


class AwaitableGetNetworkPrivateSubnetsResult(GetNetworkPrivateSubnetsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkPrivateSubnetsResult(
            id=self.id,
            network_id=self.network_id,
            service_name=self.service_name,
            subnets=self.subnets)


def get_network_private_subnets(network_id: Optional[builtins.str] = None,
                                service_name: Optional[builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkPrivateSubnetsResult:
    """
    List public cloud project subnets of a private network.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    private = ovh.CloudProject.get_network_private_subnets(service_name="XXXXXX",
        network_id="XXXXXX")
    pulumi.export("private", private)
    ```


    :param builtins.str network_id: ID of the network
    :param builtins.str service_name: The ID of the public cloud project.
    """
    __args__ = dict()
    __args__['networkId'] = network_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getNetworkPrivateSubnets:getNetworkPrivateSubnets', __args__, opts=opts, typ=GetNetworkPrivateSubnetsResult).value

    return AwaitableGetNetworkPrivateSubnetsResult(
        id=pulumi.get(__ret__, 'id'),
        network_id=pulumi.get(__ret__, 'network_id'),
        service_name=pulumi.get(__ret__, 'service_name'),
        subnets=pulumi.get(__ret__, 'subnets'))
def get_network_private_subnets_output(network_id: Optional[pulumi.Input[builtins.str]] = None,
                                       service_name: Optional[pulumi.Input[builtins.str]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkPrivateSubnetsResult]:
    """
    List public cloud project subnets of a private network.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    private = ovh.CloudProject.get_network_private_subnets(service_name="XXXXXX",
        network_id="XXXXXX")
    pulumi.export("private", private)
    ```


    :param builtins.str network_id: ID of the network
    :param builtins.str service_name: The ID of the public cloud project.
    """
    __args__ = dict()
    __args__['networkId'] = network_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getNetworkPrivateSubnets:getNetworkPrivateSubnets', __args__, opts=opts, typ=GetNetworkPrivateSubnetsResult)
    return __ret__.apply(lambda __response__: GetNetworkPrivateSubnetsResult(
        id=pulumi.get(__response__, 'id'),
        network_id=pulumi.get(__response__, 'network_id'),
        service_name=pulumi.get(__response__, 'service_name'),
        subnets=pulumi.get(__response__, 'subnets')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetProjectIamResult',
    'GetProjectsProjectResult',
    'GetProjectsProjectIamResult',
]

@pulumi.output_type
class GetProjectIamResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 tags: Mapping[str, builtins.str],
                 urn: builtins.str):
        """
        :param builtins.str display_name: Resource display name
        :param builtins.str id: Unique identifier of the resource in the IAM
        :param Mapping[str, builtins.str] tags: Resource tags. Tags that were internally computed are prefixed with `ovh:`
        :param builtins.str urn: URN of the private database, used when writing IAM policies
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Unique identifier of the resource in the IAM
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        Resource tags. Tags that were internally computed are prefixed with `ovh:`
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        """
        URN of the private database, used when writing IAM policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class GetProjectsProjectResult(dict):
    def __init__(__self__, *,
                 access: builtins.str,
                 creation_date: builtins.str,
                 description: builtins.str,
                 expiration: builtins.str,
                 iam: 'outputs.GetProjectsProjectIamResult',
                 manual_quota: builtins.bool,
                 order_id: builtins.float,
                 plan_code: builtins.str,
                 project_id: builtins.str,
                 project_name: builtins.str,
                 service_name: builtins.str,
                 status: builtins.str,
                 unleash: builtins.bool):
        """
        :param builtins.str access: Project access
        :param builtins.str creation_date: Project creation date
        :param builtins.str description: Description of your project
        :param builtins.str expiration: Expiration date of your project. After this date, your project will be deleted
        :param 'GetProjectsProjectIamArgs' iam: IAM resource information
        :param builtins.bool manual_quota: Manual quota prevent automatic quota upgrade
        :param builtins.float order_id: Project order ID
        :param builtins.str plan_code: Order plan code
        :param builtins.str project_id: Project ID
        :param builtins.str project_name: Project name
        :param builtins.str service_name: ID of the public cloud project
        :param builtins.str status: Current status
        :param builtins.bool unleash: Project unleashed
        """
        pulumi.set(__self__, "access", access)
        pulumi.set(__self__, "creation_date", creation_date)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "expiration", expiration)
        pulumi.set(__self__, "iam", iam)
        pulumi.set(__self__, "manual_quota", manual_quota)
        pulumi.set(__self__, "order_id", order_id)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "unleash", unleash)

    @property
    @pulumi.getter
    def access(self) -> builtins.str:
        """
        Project access
        """
        return pulumi.get(self, "access")

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> builtins.str:
        """
        Project creation date
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of your project
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def expiration(self) -> builtins.str:
        """
        Expiration date of your project. After this date, your project will be deleted
        """
        return pulumi.get(self, "expiration")

    @property
    @pulumi.getter
    def iam(self) -> 'outputs.GetProjectsProjectIamResult':
        """
        IAM resource information
        """
        return pulumi.get(self, "iam")

    @property
    @pulumi.getter(name="manualQuota")
    def manual_quota(self) -> builtins.bool:
        """
        Manual quota prevent automatic quota upgrade
        """
        return pulumi.get(self, "manual_quota")

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> builtins.float:
        """
        Project order ID
        """
        return pulumi.get(self, "order_id")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Order plan code
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> builtins.str:
        """
        Project ID
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        Project name
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        ID of the public cloud project
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Current status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def unleash(self) -> builtins.bool:
        """
        Project unleashed
        """
        return pulumi.get(self, "unleash")


@pulumi.output_type
class GetProjectsProjectIamResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 tags: Mapping[str, builtins.str],
                 urn: builtins.str):
        """
        :param builtins.str display_name: Resource display name
        :param builtins.str id: Unique identifier of the resource in the IAM
        :param Mapping[str, builtins.str] tags: Resource tags. Tags that were internally computed are prefixed with `ovh:`
        :param builtins.str urn: URN of the private database, used when writing IAM policies
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Unique identifier of the resource in the IAM
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        Resource tags. Tags that were internally computed are prefixed with `ovh:`
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        """
        URN of the private database, used when writing IAM policies
        """
        return pulumi.get(self, "urn")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetRedisUserResult',
    'AwaitableGetRedisUserResult',
    'get_redis_user',
    'get_redis_user_output',
]

@pulumi.output_type
class GetRedisUserResult:
    """
    A collection of values returned by getRedisUser.
    """
    def __init__(__self__, categories=None, channels=None, cluster_id=None, commands=None, created_at=None, id=None, keys=None, name=None, service_name=None, status=None):
        if categories and not isinstance(categories, list):
            raise TypeError("Expected argument 'categories' to be a list")
        pulumi.set(__self__, "categories", categories)
        if channels and not isinstance(channels, list):
            raise TypeError("Expected argument 'channels' to be a list")
        pulumi.set(__self__, "channels", channels)
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if commands and not isinstance(commands, list):
            raise TypeError("Expected argument 'commands' to be a list")
        pulumi.set(__self__, "commands", commands)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if keys and not isinstance(keys, list):
            raise TypeError("Expected argument 'keys' to be a list")
        pulumi.set(__self__, "keys", keys)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def categories(self) -> Sequence[builtins.str]:
        """
        Categories of the user.
        """
        return pulumi.get(self, "categories")

    @property
    @pulumi.getter
    def channels(self) -> Sequence[builtins.str]:
        """
        Channels of the user.
        """
        return pulumi.get(self, "channels")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def commands(self) -> Sequence[builtins.str]:
        """
        Commands of the user.
        """
        return pulumi.get(self, "commands")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        Date of the creation of the user.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def keys(self) -> Sequence[builtins.str]:
        """
        Keys of the user.
        """
        return pulumi.get(self, "keys")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Current status of the user.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Current status of the user.
        """
        return pulumi.get(self, "status")


class AwaitableGetRedisUserResult(GetRedisUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRedisUserResult(
            categories=self.categories,
            channels=self.channels,
            cluster_id=self.cluster_id,
            commands=self.commands,
            created_at=self.created_at,
            id=self.id,
            keys=self.keys,
            name=self.name,
            service_name=self.service_name,
            status=self.status)


def get_redis_user(cluster_id: Optional[builtins.str] = None,
                   name: Optional[builtins.str] = None,
                   service_name: Optional[builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRedisUserResult:
    """
    Use this data source to get information about a user of a redis cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    redis_user = ovh.CloudProject.get_redis_user(service_name="XXX",
        cluster_id="YYY",
        name="ZZZ")
    pulumi.export("redisUserCommands", redis_user.commands)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str name: Name of the user
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getRedisUser:getRedisUser', __args__, opts=opts, typ=GetRedisUserResult).value

    return AwaitableGetRedisUserResult(
        categories=pulumi.get(__ret__, 'categories'),
        channels=pulumi.get(__ret__, 'channels'),
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        commands=pulumi.get(__ret__, 'commands'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        keys=pulumi.get(__ret__, 'keys'),
        name=pulumi.get(__ret__, 'name'),
        service_name=pulumi.get(__ret__, 'service_name'),
        status=pulumi.get(__ret__, 'status'))
def get_redis_user_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                          name: Optional[pulumi.Input[builtins.str]] = None,
                          service_name: Optional[pulumi.Input[builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRedisUserResult]:
    """
    Use this data source to get information about a user of a redis cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    redis_user = ovh.CloudProject.get_redis_user(service_name="XXX",
        cluster_id="YYY",
        name="ZZZ")
    pulumi.export("redisUserCommands", redis_user.commands)
    ```


    :param builtins.str cluster_id: Cluster ID
    :param builtins.str name: Name of the user
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['name'] = name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getRedisUser:getRedisUser', __args__, opts=opts, typ=GetRedisUserResult)
    return __ret__.apply(lambda __response__: GetRedisUserResult(
        categories=pulumi.get(__response__, 'categories'),
        channels=pulumi.get(__response__, 'channels'),
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        commands=pulumi.get(__response__, 'commands'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        keys=pulumi.get(__response__, 'keys'),
        name=pulumi.get(__response__, 'name'),
        service_name=pulumi.get(__response__, 'service_name'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .get_ip_load_balancing import *
from .get_vrack_network import *
from .http_farm import *
from .http_farm_server import *
from .http_frontend import *
from .http_route import *
from .http_route_rule import *
from .load_balancer import *
from .refresh import *
from .ssl import *
from .tcp_farm import *
from .tcp_farm_server import *
from .tcp_frontend import *
from .tcp_route import *
from .tcp_route_rule import *
from .udp_farm import *
from .udp_farm_server import *
from .udp_frontend import *
from .vrack_network import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetStorageObjectResult',
    'AwaitableGetStorageObjectResult',
    'get_storage_object',
    'get_storage_object_output',
]

@pulumi.output_type
class GetStorageObjectResult:
    """
    A collection of values returned by getStorageObject.
    """
    def __init__(__self__, etag=None, id=None, is_delete_marker=None, is_latest=None, key=None, last_modified=None, name=None, region_name=None, service_name=None, size=None, storage_class=None, version_id=None):
        if etag and not isinstance(etag, str):
            raise TypeError("Expected argument 'etag' to be a str")
        pulumi.set(__self__, "etag", etag)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_delete_marker and not isinstance(is_delete_marker, bool):
            raise TypeError("Expected argument 'is_delete_marker' to be a bool")
        pulumi.set(__self__, "is_delete_marker", is_delete_marker)
        if is_latest and not isinstance(is_latest, bool):
            raise TypeError("Expected argument 'is_latest' to be a bool")
        pulumi.set(__self__, "is_latest", is_latest)
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if last_modified and not isinstance(last_modified, str):
            raise TypeError("Expected argument 'last_modified' to be a str")
        pulumi.set(__self__, "last_modified", last_modified)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region_name and not isinstance(region_name, str):
            raise TypeError("Expected argument 'region_name' to be a str")
        pulumi.set(__self__, "region_name", region_name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if size and not isinstance(size, float):
            raise TypeError("Expected argument 'size' to be a float")
        pulumi.set(__self__, "size", size)
        if storage_class and not isinstance(storage_class, str):
            raise TypeError("Expected argument 'storage_class' to be a str")
        pulumi.set(__self__, "storage_class", storage_class)
        if version_id and not isinstance(version_id, str):
            raise TypeError("Expected argument 'version_id' to be a str")
        pulumi.set(__self__, "version_id", version_id)

    @property
    @pulumi.getter
    def etag(self) -> builtins.str:
        """
        ETag
        """
        return pulumi.get(self, "etag")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isDeleteMarker")
    def is_delete_marker(self) -> builtins.bool:
        """
        Whether this object is a delete marker
        """
        return pulumi.get(self, "is_delete_marker")

    @property
    @pulumi.getter(name="isLatest")
    def is_latest(self) -> builtins.bool:
        """
        Whether this is the latest version of the object
        """
        return pulumi.get(self, "is_latest")

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        Key
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter(name="lastModified")
    def last_modified(self) -> builtins.str:
        """
        Last modification date
        """
        return pulumi.get(self, "last_modified")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> builtins.str:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def size(self) -> builtins.float:
        """
        Size (bytes)
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="storageClass")
    def storage_class(self) -> builtins.str:
        """
        Storage class
        """
        return pulumi.get(self, "storage_class")

    @property
    @pulumi.getter(name="versionId")
    def version_id(self) -> builtins.str:
        """
        Version ID of the object
        """
        return pulumi.get(self, "version_id")


class AwaitableGetStorageObjectResult(GetStorageObjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStorageObjectResult(
            etag=self.etag,
            id=self.id,
            is_delete_marker=self.is_delete_marker,
            is_latest=self.is_latest,
            key=self.key,
            last_modified=self.last_modified,
            name=self.name,
            region_name=self.region_name,
            service_name=self.service_name,
            size=self.size,
            storage_class=self.storage_class,
            version_id=self.version_id)


def get_storage_object(key: Optional[builtins.str] = None,
                       name: Optional[builtins.str] = None,
                       region_name: Optional[builtins.str] = None,
                       service_name: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStorageObjectResult:
    """
    Get information about an object in a S3™* compatible storage container. \\* S3 is a trademark filed by Amazon Technologies,Inc. OVHcloud's service is not sponsored by, endorsed by, or otherwise affiliated with Amazon Technologies,Inc.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    object = ovh.CloudProject.get_storage_object(service_name="<public cloud project ID>",
        region_name="GRA",
        name="<bucket name>",
        key="<object name>")
    ```


    :param builtins.str key: Key
    :param builtins.str name: Name
    :param builtins.str region_name: Region name
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['key'] = key
    __args__['name'] = name
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getStorageObject:getStorageObject', __args__, opts=opts, typ=GetStorageObjectResult).value

    return AwaitableGetStorageObjectResult(
        etag=pulumi.get(__ret__, 'etag'),
        id=pulumi.get(__ret__, 'id'),
        is_delete_marker=pulumi.get(__ret__, 'is_delete_marker'),
        is_latest=pulumi.get(__ret__, 'is_latest'),
        key=pulumi.get(__ret__, 'key'),
        last_modified=pulumi.get(__ret__, 'last_modified'),
        name=pulumi.get(__ret__, 'name'),
        region_name=pulumi.get(__ret__, 'region_name'),
        service_name=pulumi.get(__ret__, 'service_name'),
        size=pulumi.get(__ret__, 'size'),
        storage_class=pulumi.get(__ret__, 'storage_class'),
        version_id=pulumi.get(__ret__, 'version_id'))
def get_storage_object_output(key: Optional[pulumi.Input[builtins.str]] = None,
                              name: Optional[pulumi.Input[builtins.str]] = None,
                              region_name: Optional[pulumi.Input[builtins.str]] = None,
                              service_name: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetStorageObjectResult]:
    """
    Get information about an object in a S3™* compatible storage container. \\* S3 is a trademark filed by Amazon Technologies,Inc. OVHcloud's service is not sponsored by, endorsed by, or otherwise affiliated with Amazon Technologies,Inc.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    object = ovh.CloudProject.get_storage_object(service_name="<public cloud project ID>",
        region_name="GRA",
        name="<bucket name>",
        key="<object name>")
    ```


    :param builtins.str key: Key
    :param builtins.str name: Name
    :param builtins.str region_name: Region name
    :param builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['key'] = key
    __args__['name'] = name
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getStorageObject:getStorageObject', __args__, opts=opts, typ=GetStorageObjectResult)
    return __ret__.apply(lambda __response__: GetStorageObjectResult(
        etag=pulumi.get(__response__, 'etag'),
        id=pulumi.get(__response__, 'id'),
        is_delete_marker=pulumi.get(__response__, 'is_delete_marker'),
        is_latest=pulumi.get(__response__, 'is_latest'),
        key=pulumi.get(__response__, 'key'),
        last_modified=pulumi.get(__response__, 'last_modified'),
        name=pulumi.get(__response__, 'name'),
        region_name=pulumi.get(__response__, 'region_name'),
        service_name=pulumi.get(__response__, 'service_name'),
        size=pulumi.get(__response__, 'size'),
        storage_class=pulumi.get(__response__, 'storage_class'),
        version_id=pulumi.get(__response__, 'version_id')))
